@@ -3,10 +3,9 @@ use ExtUtils::MakeMaker;
 
 WriteMakefile(
   NAME             => 'AsposeSlidesCloud::SlidesApi',
-  VERSION          => 19.12,
+  VERSION_FROM     => 'lib/AsposeSlidesCloud/SlidesApi.pm',
   ABSTRACT         => 'Aspose.Slides Cloud SDK',
   AUTHOR           => 'Victor Putrov',
   LICENSE          => 'MIT',
-  MIN_PERL_VERSION => '5.008004',
-  EXE_FILES        => ['lib/AsposeSlidesCloud']
+  MIN_PERL_VERSION => '5.008004'
 );
\ No newline at end of file
